# Splitting

::: torchlinops.linops.split_linop

::: torchlinops.linops.create_batched_linop

::: torchlinops.linops.BatchSpec
    options:
        inherited_members: false
        members:
            - __init__
            - broadcast_device_matrix
